@@ -39,7 +39,7 @@ echo -
 #  bash tools/testers/update-tester.sh
 #
 
-CURRENT=2.3.1
+CURRENT=2.4.2
 
 function update_test {
 set -e
@@ -75,13 +75,22 @@ dropdb   ___test_update
 ### updates from 2.3.0
 #------------------------------------
 
+update_test 2.4.1 $CURRENT
+update_test 2.4.0 $CURRENT
+
+#------------------------------------
+### updates from 2.3.0
+#------------------------------------
+
+#update_test 2.3.2 $CURRENT
+update_test 2.3.1 $CURRENT
 update_test 2.3.0 $CURRENT
 
 #------------------------------------
 ### updates from 2.2.x
 #------------------------------------
 
-update_test 2.2.4 $CURRENT
+#update_test 2.2.4 $CURRENT
 update_test 2.2.3 $CURRENT
 update_test 2.2.2 $CURRENT
 update_test 2.2.1 $CURRENT
@@ -103,4 +112,4 @@ update_test 2.0.0 $CURRENT
 echo Reached end of test, all tests passed
 # CAN NOT BE Update test from 2.0.1  to $CURRENT;
 
-
+exit 0
