@@ -10,6 +10,10 @@
 set -e 
 
 # build pgRouting
-cmake -DWITH_DD=ON 
+mkdir build
+cd build
+cmake  -DPOSTGRESQL_VERSION=$POSTGRESQL_VERSION -DWITH_DOC=ON -DBUILD_DOXY=ON -DCMAKE_BUILD_TYPE=Debug ..
 make
 sudo make install
+make doc
+make doxy
